@@ -78,7 +78,7 @@ def render(html, defaults={}, errors={}):
                 apply_to(node, tag,
                          defaults[node.attrib.get("name")])
 
-    html = "%s%s%s" % (html_pre, ElementTree.tostring(dom, "utf-8"), html_post)
+    html = "%s%s%s" % (html_pre, ElementTree.tostring(dom), html_post)
 
     # Deal with error tags
     for node in dom.getiterator("error"):
@@ -93,7 +93,7 @@ def render(html, defaults={}, errors={}):
                 if string == None:
                     string = ""
                     continue
-                string += ElementTree.tostring(child, "utf-8")
+                string += ElementTree.tostring(child)
             if string.find("%s") >= 0:
                 string = string.replace("#%", "%")
                 error_msg = (errors[node.attrib.get("for")])
@@ -101,4 +101,4 @@ def render(html, defaults={}, errors={}):
                     error_msg = tuple(error_msg[0])
                 string = string % error_msg
         html = html[0:serror_start]+string+html[eerror_start+len("</script>")+1:]
-    return html
+    return str(html)
